function varargout = M_gui(varargin)
% M_GUI MATLAB code for M_gui.fig
%      M_GUI, by itself, creates a new M_GUI or raises the existing
%      singleton*.
%
%      H = M_GUI returns the handle to a new M_GUI or the handle to
%      the existing singleton*.
%
%      M_GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in M_GUI.M with the given input arguments.
%
%      M_GUI('Property','Value',...) creates a new M_GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before M_gui_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to M_gui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help M_gui

% Last Modified by GUIDE v2.5 07-Jun-2015 19:54:32

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @M_gui_OpeningFcn, ...
                   'gui_OutputFcn',  @M_gui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before M_gui is made visible.
function M_gui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to M_gui (see VARARGIN)

handles.pb1cnt = 0;


% Choose default command line output for M_gui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes M_gui wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = M_gui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles.f_cnt = 0;
% Get default command line output from handles structure
varargout{1} = handles.output;
guidata(hObject, handles);

% --- Executes on button press in pb_f_up.
function pb_f_up_Callback(hObject, eventdata, handles)
% hObject    handle to pb_f_up (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
f_cnt = handles.f_cnt;
f_cnt = f_cnt + 1;
handles.f_cnt = f_cnt;
% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in pb_f_down.
function pb_f_down_Callback(hObject, eventdata, handles)
% hObject    handle to pb_f_down (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
f_cnt = handles.f_cnt;
if(f_cnt >= 1)
  f_cnt = f_cnt - 1;
end
handles.f_cnt = f_cnt;
% Update handles structure
guidata(hObject, handles);
